@@ -48,7 +48,6 @@ def Redondear(expr):#Redondeamos la expresión.
 
 
 def D(elemento,color = "red"):#Por default se imprime en rojo, para indicar que es un derivado.
-  print("")
   Tipo = None
   if isinstance(elemento,sympy.core.relational.Equality):#Si el elemento ingresado es una ecuación, entonces la identificamos
     Tipo = "Ecuacion"
@@ -67,30 +66,24 @@ def D(elemento,color = "red"):#Por default se imprime en rojo, para indicar que
     texto = a+b+c
     texto = texto.replace("text", Estilo)
 
-    IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
+    IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}")
 
   if Tipo == "Componente":#Si hemos identificado el elemento ingresado como un componente, entonces lo imprimimos en rojo
-    if not isinstance(c_componente[0],str):#isinstance(c_componente[0],sy.core.symbol.Symbol) or isinstance(c_componente[0],sy.core.symbol.Symbol) :
-      a = sympy.latex(c_componente[0])
+    if c_componente[1] == None:
+      mascara = "\\cdots"
+    else:
+      mascara = c_componente[1]
 
-      b = " = "
+    #if not isinstance(c_componente[0],str):#isinstance(c_componente[0],sy.core.symbol.Symbol) or isinstance(c_componente[0],sy.core.symbol.Symbol) :
+    a = sympy.latex(c_componente[0])
 
-      c = sympy.latex(Redondear(c_componente[1]))
+    b = " = "
 
-      texto = a + b + c
-      texto = texto.replace("text", Estilo)
-      IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
-    elif isinstance(c_componente[0],str):
-      a = sympy.latex(c_componente[0])
-      
-      b = " = "
+    c = sympy.latex(Redondear(mascara))
 
-      c = sympy.latex(Redondear(c_componente[1]))
-
-      texto = a + b + c
-      texto = texto.replace("text", Estilo)
-      IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
-  #Código para actualizar valores: if isinstance(element[1], sy.Expr):element = [element[0],element[1].subs(c_componente[0],c_componente[1])]
+    texto = a + b + c
+      #texto = texto.replace("text", Estilo)
+    IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}")
 
 
 #def E(expr,color = "red"):
